<p align="center">
  <img width="500" height="400" src="Images/logo.png">
</p>

<div align="center">
<h1>seeFretboard: Unlocking Boundless Possibilities for Music Education, Research, and Creative Exploration</h1>
</div>

The seeFretboard Python library allows users to visualize guitar fretboards. Providing foundational music theory displays with intervals, chords, arpeggios, and scales. It also has features such as dynamic video creation of the visualized fretboards with integration of audio.


## Installation
[Anaconda Installation/Docunmentation](https://docs.anaconda.com/free/anaconda/install/index.html)
<br>
Install With Conda Environment
```bash
conda create --name <env> --file Conda-package-list.txt
```
[Pip Installation/Docunmentation](https://pip.pypa.io/en/stable/)
<br>
Install with Pip Files
```bash
pip install -r requirements.txt
```

Install with Pip

```bash
pip install seeFretboard
```
## Features

- Customization of styles, designs, and other visual elements
- Display horizontal and vertical fretboards
- Display intervals, arpeggios, scales, custom arpeggios, and custom scales
- Display drop2, drop3, and CAGED chord shape and custom chords
- Create dynamic videos of visualized fretboard
- Generate MIDI audio
- Combine videos with audio (mp3, wav, MIDI, etc) to create synchronized multimedia content
- Support for prediction vs ground truth, beneficial for music information retrieval researchers working on guitar transcription
- Suitable for integration into websites, applications, or standalone usage.
- Potential for future developments, such as templates, deliberate practice tools, voicings, repetition, reflection exercises, quizzes, textbooks, games, and advanced techniques for fretboard visualization, manipulation, learnings, and AI/ML assistance.


## Documentations

- [ReadTheDocs](https://seefretboard.readthedocs.io/en/latest/)
- [Colab Examples](https://colab.research.google.com/drive/1ph2_gWhY4UMN_gLa4Ab9w2uEYFbGuFOA?usp=sharing)

## Contributing

Contributions are always welcome! We appreciate it! 

See [CONTRIBUTING.rst](CONTRIBUTING.rst) for ways to get started.


## Credits
Thank you for your contributions! We appreciate it!

## Creator
This project was created by Linda Rong Zhang.
- [Github](https://github.com/LindaRZhang) 
- [Email](mailto:ronglindaz@gmail.com)

## History
[HISTORY](HISTORY.rst)



